@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
 
-"""
-Tests for Email generator
-"""
+"""Tests for Email generator."""
 
-from fauxfactory import FauxFactory
+from fauxfactory import gen_email
 
 import re
 import unittest
@@ -13,19 +11,9 @@ REGEX = r"^[a-zA-Z][a-zA-Z-.]*[^.-]@\w*\.[a-zA-Z]{2,3}"
 
 
 class TestEmails(unittest.TestCase):
-    """
-    Test Email generator
-    """
+    """Test Email generator."""
 
-    @classmethod
-    def setUpClass(cls):
-        """
-        Instantiate our factory object
-        """
-
-        cls.factory = FauxFactory()
-
-    def test_generate_email_1(self):
+    def test_gen_email_1(self):
         """
         @Test: Create a random email value
         @Feature: Email Generator
@@ -35,7 +23,8 @@ class TestEmails(unittest.TestCase):
         # Regex for email validation
         emailinator = re.compile(REGEX)
         for turn in range(100):
-            result = self.factory.generate_email()
+            result = gen_email()
 
-            self.assertIsNotNone(emailinator.match(result),
-                                 "A valid email value was not generated.")
+            self.assertIsNotNone(
+                emailinator.match(result),
+                "A valid email value was not generated.")
