@@ -1,29 +1,23 @@
 # -*- coding: utf-8 -*-
 
-"""
-Tests for URL generator
-"""
+"""Tests for URL generator."""
 
 import unittest
 
-from fauxfactory import FauxFactory
+from fauxfactory import (
+    gen_alpha,
+    gen_alphanumeric,
+    gen_cjk,
+    gen_numeric_string,
+    gen_url,
+)
 from fauxfactory.constants import SCHEMES
 
 
 class TestURLs(unittest.TestCase):
-    """
-    Test URL generator
-    """
+    """Test URL generator."""
 
-    @classmethod
-    def setUpClass(cls):
-        """
-        Instantiate our factory object
-        """
-
-        cls.factory = FauxFactory()
-
-    def test_generate_url_1(self):
+    def test_gen_url_1(self):
         """
         @Test: Create a random URL
         @Feature: URL Generator
@@ -31,7 +25,7 @@ class TestURLs(unittest.TestCase):
         """
 
         for turn in range(10):
-            result = self.factory.generate_url()
+            result = gen_url()
             self.assertTrue(
                 len(result) > 0,
                 "A valid URL was not generated.")
@@ -40,7 +34,7 @@ class TestURLs(unittest.TestCase):
                 "URL does not start with a valid scheme"
             )
 
-    def test_generate_url_2(self):
+    def test_gen_url_2(self):
         """
         @Test: Create a random URL with http scheme
         @Feature: URL Generator
@@ -48,7 +42,7 @@ class TestURLs(unittest.TestCase):
         """
 
         for turn in range(10):
-            result = self.factory.generate_url(scheme='http')
+            result = gen_url(scheme='http')
             self.assertTrue(
                 len(result) > 0,
                 "A valid URL was not generated.")
@@ -57,7 +51,7 @@ class TestURLs(unittest.TestCase):
                 "URL does not start with http"
             )
 
-    def test_generate_url_3(self):
+    def test_gen_url_3(self):
         """
         @Test: Create a random URL with https scheme
         @Feature: URL Generator
@@ -65,7 +59,7 @@ class TestURLs(unittest.TestCase):
         """
 
         for turn in range(10):
-            result = self.factory.generate_url(scheme='https')
+            result = gen_url(scheme='https')
             self.assertTrue(
                 len(result) > 0,
                 "A valid URL was not generated.")
@@ -74,7 +68,7 @@ class TestURLs(unittest.TestCase):
                 "URL does not start with https"
             )
 
-    def test_generate_url_4(self):
+    def test_gen_url_4(self):
         """
         @Test: Create a random URL with ftp scheme
         @Feature: URL Generator
@@ -82,7 +76,7 @@ class TestURLs(unittest.TestCase):
         """
 
         for turn in range(10):
-            result = self.factory.generate_url(scheme='ftp')
+            result = gen_url(scheme='ftp')
             self.assertTrue(
                 len(result) > 0,
                 "A valid URL was not generated.")
@@ -91,7 +85,7 @@ class TestURLs(unittest.TestCase):
                 "URL does not start with ftp"
             )
 
-    def test_generate_url_5(self):
+    def test_gen_url_5(self):
         """
         @Test: Create a random URL with invalid scheme
         @Feature: URL Generator
@@ -99,11 +93,11 @@ class TestURLs(unittest.TestCase):
         """
 
         for turn in range(10):
-            scheme = self.factory.generate_alphanumeric()
+            scheme = gen_alphanumeric()
             with self.assertRaises(ValueError):
-                self.factory.generate_url(scheme=scheme)
+                gen_url(scheme=scheme)
 
-    def test_generate_url_6(self):
+    def test_gen_url_6(self):
         """
         @Test: Create a random URL with valid subdomain
         @Feature: URL Generator
@@ -111,8 +105,8 @@ class TestURLs(unittest.TestCase):
         """
 
         for turn in range(10):
-            subdomain = self.factory.generate_alphanumeric()
-            result = self.factory.generate_url(subdomain=subdomain)
+            subdomain = gen_alphanumeric()
+            result = gen_url(subdomain=subdomain)
             self.assertTrue(
                 len(result) > 0,
                 "A valid URL was not generated.")
@@ -124,19 +118,19 @@ class TestURLs(unittest.TestCase):
                 domain[0] == subdomain
             )
 
-    def test_generate_url_7(self):
+    def test_gen_url_7(self):
         """
         @Test: Create a random URL with empty subdomain
         @Feature: URL Generator
         @Assert: URL should be created with a random subdomain
         """
 
-        result = self.factory.generate_url(subdomain='')
+        result = gen_url(subdomain='')
         self.assertTrue(
             len(result) > 0,
             "A valid URL was not generated.")
 
-    def test_generate_url_8(self):
+    def test_gen_url_8(self):
         """
         @Test: Create a random URL with whitespace subdomain
         @Feature: URL Generator
@@ -144,9 +138,9 @@ class TestURLs(unittest.TestCase):
         """
 
         with self.assertRaises(ValueError):
-            self.factory.generate_url(subdomain=" ")
+            gen_url(subdomain=" ")
 
-    def test_generate_url_9(self):
+    def test_gen_url_9(self):
         """
         @Test: Create a random URL with invalid subdomain
         @Feature: URL Generator
@@ -154,11 +148,11 @@ class TestURLs(unittest.TestCase):
         """
 
         for turn in range(10):
-            subdomain = self.factory.generate_cjk()
+            subdomain = gen_cjk()
             with self.assertRaises(ValueError):
-                self.factory.generate_url(subdomain=subdomain)
+                gen_url(subdomain=subdomain)
 
-    def test_generate_url_10(self):
+    def test_gen_url_10(self):
         """
         @Test: Create a random URL with valid TLDS
         @Feature: URL Generator
@@ -166,8 +160,8 @@ class TestURLs(unittest.TestCase):
         """
 
         for turn in range(10):
-            tlds = self.factory.generate_alpha(length=3)
-            result = self.factory.generate_url(tlds=tlds)
+            tlds = gen_alpha(length=3)
+            result = gen_url(tlds=tlds)
             self.assertTrue(
                 len(result) > 0,
                 "A valid URL was not generated.")
@@ -176,7 +170,7 @@ class TestURLs(unittest.TestCase):
                 "URL does not have the TLDS specified"
             )
 
-    def test_generate_url_11(self):
+    def test_gen_url_11(self):
         """
         @Test: Create a random URL with numeric TLDS
         @Feature: URL Generator
@@ -185,10 +179,10 @@ class TestURLs(unittest.TestCase):
 
         for turn in range(10):
             with self.assertRaises(ValueError):
-                tlds = self.factory.generate_numeric_string(length=3)
-                self.factory.generate_url(tlds=tlds)
+                tlds = gen_numeric_string(length=3)
+                gen_url(tlds=tlds)
 
-    def test_generate_url_12(self):
+    def test_gen_url_12(self):
         """
         @Test: Create a random URL with whitespace TLDS
         @Feature: URL Generator
@@ -197,4 +191,4 @@ class TestURLs(unittest.TestCase):
 
         for turn in range(10):
             with self.assertRaises(ValueError):
-                self.factory.generate_url(tlds=" ")
+                gen_url(tlds=" ")
